@@ -46,7 +46,7 @@ AbstractBackend::Capabilities Motis2Backend::capabilities() const
 
 Location::Types Motis2Backend::supportedLocationTypes() const
 {
-    return Location::Stop | Location::Address;
+    return Location::Stop | Location::Address | Location::RentedVehicle | Location::RentedVehicleStation;
 }
 
 bool Motis2Backend::needsLocationQuery(const Location &loc, AbstractBackend::QueryType type) const
@@ -102,6 +102,35 @@ bool Motis2Backend::queryLocation(const LocationRequest &req, LocationReply *rep
         return true;
     }
 
+    if (req.hasCoordinate() && (req.types() & (Location::RentedVehicle | Location::RentedVehicleStation)) == req.types()) {
+        const auto dlat = req.maximumDistance() / Location::distance(req.latitude(), 0.0, req.latitude(), 1.0);
+        const auto dlon = req.maximumDistance() / Location::distance(0.0, req.longitude(), 1.0, req.longitude());
+        query.addQueryItem(u"min"_s, QString::number(req.latitude() - dlat) + ','_L1 + QString::number(req.longitude() - dlon));
+        query.addQueryItem(u"max"_s, QString::number(req.latitude() + dlat) + ','_L1 + QString::number(req.longitude() + dlon));
+        query.addQueryItem(u"withProviders"_s, u"true"_s);
+        query.addQueryItem(u"withVehicles"_s, req.types() & Location::RentedVehicle ? u"true"_s : u"false"_s);
+        query.addQueryItem(u"withStations"_s, req.types() & Location::RentedVehicleStation ? u"true"_s : u"false"_s);
+        query.addQueryItem(u"withZones"_s, u"false"_s);
+
+        netReply = makeRequest(req, reply, "v1/map/rentals"_L1, query, nam); // TODO v2.7 - without "maps/"
+        QObject::connect(netReply, &QNetworkReply::finished, reply, [this, reply, netReply]() {
+            netReply->deleteLater();
+            const auto data = netReply->readAll();
+            logReply(reply, netReply, data);
+
+            Motis2Parser p(m_locationIdentifierType);
+            auto result = p.parseRentals(data);
+
+            if (netReply->error() == QNetworkReply::NoError) {
+                // no caching, these are realtime data results
+                addResult(reply, std::move(result));
+            } else {
+                addError(reply, Reply::NetworkError, netReply->errorString() + ' '_L1 + QString::fromUtf8(data));
+            }
+        });
+        return true;
+    }
+
     if (req.hasCoordinate()) {
         query.addQueryItem(u"place"_s, QString::number(req.latitude()) + ','_L1 + QString::number(req.longitude()));
         if (req.types() == Location::Stop) {
@@ -112,7 +141,6 @@ bool Motis2Backend::queryLocation(const LocationRequest &req, LocationReply *rep
         netReply = makeRequest(req, reply, "v1/reverse-geocode"_L1, query, nam);
     } else {
         query.addQueryItem(u"text"_s, req.name());
-        query.addQueryItem(u"language"_s, preferredLanguage());
         if (req.types() == Location::Stop) {
             query.addQueryItem(u"type"_s, u"STOP"_s);
         } else if (req.types() == Location::Address) {
@@ -219,7 +247,7 @@ struct {
     { Line::LongDistanceTrain, "NIGHT_RAIL" },
     { Line::Metro, "SUBWAY" },
     { Line::RailShuttle, "RAIL" },
-    { Line::RapidTransit, "METRO" },
+    { Line::RapidTransit, "SUBURBAN" },
     { Line::Shuttle, "BUS" },
     { Line::Shuttle, "COACH" },
     { Line::Taxi, "FLEXIBLE" },
@@ -228,7 +256,8 @@ struct {
     { Line::Tramway, "TRAM" },
     { Line::Tramway, "CABLE_CAR" },
     { Line::RideShare, "CAR_SHARING" },
-    { Line::AerialLift, "AREAL_LIFT" },
+    { Line::RideShare, "RIDE_SHARING" },
+    { Line::AerialLift, "AERIAL_LIFT" },
 };
 
 struct {
@@ -405,8 +434,18 @@ bool Motis2Backend::queryTrip(const TripRequest &req, TripReply *reply, QNetwork
 }
 
 template <typename Request>
-QNetworkReply* Motis2Backend::makeRequest(const Request &req, QObject *parent, QLatin1StringView command, const QUrlQuery &query, QNetworkAccessManager *nam) const
+QNetworkReply* Motis2Backend::makeRequest(const Request &req, QObject *parent, QLatin1StringView command, QUrlQuery query, QNetworkAccessManager *nam) const
 {
+    QStringList langs;
+    const auto localeLangs = QLocale().uiLanguages();
+    for (const auto &l : localeLangs) {
+        const auto baseLang = QStringView(l).left(2);
+        if (!langs.contains(baseLang)) {
+            langs.push_back(baseLang.toString());
+        }
+    }
+    query.addQueryItem(u"language"_s, langs.join(','_L1));
+
     auto url = m_endpoint;
     url.setPath("/api/"_L1 + command);
     url.setQuery(query);
